@@ -41,15 +41,14 @@ provided by L<PPI::Statement>, L<PPI::Node> and L<PPI::Element>.
 =cut
 
 use strict;
-use base 'PPI::Statement';
+use PPI::Statement ();
 
-use vars qw{$VERSION};
-BEGIN {
-	$VERSION = '1.203';
-}
+our $VERSION = '1.270'; # VERSION
+
+our @ISA = "PPI::Statement";
 
 # A null statement is not significant
-sub significant { '' }
+sub significant() { '' }
 
 1;
 
@@ -65,7 +64,7 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2008 Adam Kennedy.
+Copyright 2001 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
