@@ -27,18 +27,21 @@ represents a cast. In this case, an array dereference.
 There are no additional methods beyond those provided by the parent
 L<PPI::Token> and L<PPI::Element> classes.
 
-Got any ideas for methods? Submit a report to rt.cpan.org!
-
 =cut
 
 use strict;
-use base 'PPI::Token';
+use PPI::Token ();
 
-use vars qw{$VERSION};
-BEGIN {
-	$VERSION = '1.201';
-}
+our $VERSION = '1.270'; # VERSION
 
+our @ISA = "PPI::Token";
+
+our %POSTFIX = map { $_ => 1 } (
+	qw{
+	%* @* $*
+	},
+	'$#*' # throws warnings if it's inside a qw
+);
 
 
 
@@ -47,8 +50,16 @@ BEGIN {
 # Tokenizer Methods
 
 # A cast is either % @ $ or $#
+# and also postfix dereference are %* @* $* $#*
 sub __TOKENIZER__on_char {
-	$_[1]->_finalize_token->__TOKENIZER__on_char( $_[1] );
+	my $t    = $_[1];
+	my $char = substr( $t->{line}, $t->{line_cursor}, 1 );
+
+	# Are we still an operator if we add the next character
+	my $content = $t->{token}->{content};
+	return 1 if $POSTFIX{ $content . $char };
+
+	$t->_finalize_token->__TOKENIZER__on_char( $t );
 }
 
 1;
@@ -65,7 +76,7 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2006 Adam Kennedy.
+Copyright 2001 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
