@@ -19,15 +19,9 @@ use strict;
 use Carp          ();
 use List::Util    ();
 use PPI::Document ();
-use Params::Util '_INSTANCE',
-                 '_CLASS',
-                 '_CODE',
-                 '_SCALAR0';
+use Params::Util  qw{_INSTANCE _CLASS _CODE _SCALAR0};
 
-use vars qw{$VERSION};
-BEGIN {
-	$VERSION = '1.201';
-}
+our $VERSION = '1.270'; # VERSION
 
 
 
@@ -36,8 +30,8 @@ BEGIN {
 #####################################################################
 # Apply Handler Registration
 
-my %HANDLER = ();
-my @ORDER   = ();
+my %HANDLER;
+my @ORDER;
 
 # Yes, you can use this yourself.
 # I'm just leaving it undocumented for now.
@@ -57,7 +51,7 @@ sub register_apply_handler {
 
 # Register the default handlers
 __PACKAGE__->register_apply_handler( 'SCALAR', \&_SCALAR_get, \&_SCALAR_set );
-__PACKAGE__->register_apply_handler( 'PPI::Document', sub { $_[0] }, sub { 1 } );
+__PACKAGE__->register_apply_handler( 'PPI::Document', sub { $_[0] }, sub() { 1 } );
 
 
 
@@ -68,7 +62,12 @@ __PACKAGE__->register_apply_handler( 'PPI::Document', sub { $_[0] }, sub { 1 } )
 
 =pod
 
-=head2 new [ param1 => $value, param2 => $value ]
+=head2 new
+
+  my $transform = PPI::Transform->new(
+      param1 => 'value1',
+      param2 => 'value2',
+  );
 
 The C<new> constructor creates a new object for your C<PPI::Transform>
 subclass. A default constructor is provided for you which takes no params
@@ -77,14 +76,14 @@ and creates a basic, empty, object.
 If you wish to have your transform constructor take params, these B<must>
 be in the form of a list of key/value pairs.
 
-Returns a new C<PPI::Transform>-compatible object, or C<undef> if provided
-bad constructor params.
+Returns a new C<PPI::Transform>-compatible object, or returns
+C<undef> on error.
 
 =cut
 
 sub new {
-	my $class = ref $_[0] ? ref shift : shift;
-	bless {}, $class;
+	my $class = shift;
+	bless { @_ }, $class;
 }
 
 =pod
@@ -99,15 +98,19 @@ That's right, this method B<will not clone> and B<should not clone>
 the document object. If you do not want the original to be modified,
 you need to clone it yourself before passing it in.
 
-Returns the document anyway, as a convenience, or C<undef> if an error
-occurs. By default this error should just be that you passed in something
+Returns the numbers of changes made to the document. If the transform
+is unable to track the quantity (including the situation where it cannot
+tell B<IF> it made a change) it should return 1. Returns zero if no
+changes were made to the document, or C<undef> if an error occurs.
+
+By default this error is likely to only mean that you passed in something
 that wasn't a L<PPI::Document>, but may include additional errors
 depending on the subclass.
 
 =cut
 
 sub document {
-	my $class = ref $_[0] ? ref shift : shift;
+	my $class = shift;
 	die "$class does not implement the required ->document method";
 }
 
@@ -117,7 +120,7 @@ sub document {
 
 The C<apply> method is used to apply the transform to something. The
 argument must be a L<PPI::Document>, or something which can be turned
-into a one and then be written back to again.
+into one and then be written back to again.
 
 Currently, this list is limited to a C<SCALAR> reference, although a
 handler registration process is available for you to add support for
@@ -137,7 +140,8 @@ sub apply {
 	my $class = _SCALAR0($it) ? 'SCALAR'
 		: List::Util::first { _INSTANCE($it, $_) } @ORDER
 		or return undef;
-	my $handler = $HANDLER{$class} or die "->apply handler for $class missing! Panic";
+	my $handler = $HANDLER{$class}
+		or die("->apply handler for $class missing! Panic");
 
 	# Get, change, set
 	my $Document = _INSTANCE($handler->[0]->($it), 'PPI::Document')
@@ -150,7 +154,13 @@ sub apply {
 
 =pod
 
-=head2 file $filename [, $output ]
+=head2 file
+
+  # Read from one file and write to another
+  $transform->file( 'Input.pm' => 'Output.pm' );
+  
+  # Change a file in place
+  $transform->file( 'Change.pm' );
 
 The C<file> method modifies a Perl document by filename. If passed a single
 parameter, it modifies the file in-place. If provided a second parameter,
@@ -164,9 +174,9 @@ sub file {
 	my $self = _SELF(shift);
 
 	# Where do we read from and write to
-	my $input    = defined $_[0] ? shift : return undef;
-	my $output   = @_ ? defined $_[0] ? "$_[0]" : undef : $input or return undef;
-	
+	my $input  = defined $_[0] ? shift : return undef;
+	my $output = @_ ? defined $_[0] ? "$_[0]" : undef : $input or return undef;
+
 	# Process the file
 	my $Document = PPI::Document->new( "$input" ) or return undef;
 	$self->document( $Document )                  or return undef;
@@ -181,13 +191,12 @@ sub file {
 # Apply Hander Methods
 
 sub _SCALAR_get {
-	my $it = shift;
-	PPI::Document->new( $it );
+	PPI::Document->new( $_[0] );
 }
 
 sub _SCALAR_set {
-	my ($it, $Document) = @_;
-	$$it = $Document->serialize;
+	my $it = shift;
+	$$it = $_[0]->serialize;
 	1;
 }
 
@@ -202,7 +211,7 @@ sub _SELF {
 	return shift if ref $_[0];
 	my $self = $_[0]->new or Carp::croak(
 		"Failed to auto-instantiate new $_[0] object"
-		);
+	);
 	$self;
 }
 
@@ -210,11 +219,6 @@ sub _SELF {
 
 =pod
 
-=head1 TO DO
-
-- May need to overload some methods to forcefully prevent Document
-objects becoming children of another Node.
-
 =head1 SUPPORT
 
 See the L<support section|PPI/SUPPORT> in the main module.
@@ -225,7 +229,7 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2006 Adam Kennedy.
+Copyright 2001 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
